{ config, lib, pkgs, inputs, ... }:

{
  imports = [
    ./hardware-configuration.nix
    ../server.nix
  ];

  networking.hostId = "731d1660";

  hardware = {
    raspberry-pi."4" = {
      apply-overlays-dtmerge.enable = true;
      audio.enable = false;
      fkms-3d.enable = false;
      xhci.enable = false;
    };
    deviceTree = {
      enable = true;
      overlays = [
        { name = "hifiberry-digi-pro"; dtboFile = "${pkgs.device-tree_rpi.overlays}/hifiberry-digi-pro.dtbo"; }
      ];
    };
    firmware = with pkgs; [
      firmwareLinuxNonfree
      wireless-regdb
    ];
  };

  sound.enable = true;

  age.secrets."passwords/networks.age" = {
    file = "${inputs.secrets}/passwords/networks.age";
  };

  networking = {
    wireless = {
      enable = true;
      interfaces = [ "wlan0" ];
      environmentFile = config.age.secrets."passwords/networks.age".path;
      networks = {
        "Apollo 600 Mbps".psk = "@PSK_APOLLO@";
      };
    };
  };

  security.rtkit.enable = true;
  services.pipewire = {
    enable = true;
    alsa.enable = true;
    alsa.support32Bit = true;
    pulse.enable = true;
    systemWide = true;
  };

  services.mosquitto = {
    enable = true;
    listeners = [{
      port = 1883;
      settings = {
        allow_anonymous = true;
      };
    }];
  };

  services.zigbee2mqtt = {
    enable = true;
    settings = {
      homeassistant = config.services.home-assistant.enable;
      frontend = true;
      serial = {
        port = "/dev/ttyUSB0";
      };
      mqtt = {
        server = "mqtt://localhost:1883";
      };
    };
  };

  environment.systemPackages = with pkgs; [
    libraspberrypi
    raspberrypi-eeprom
  ];

  system.stateVersion = "22.11";
}

